@@ -2,7 +2,8 @@
 {
 if(any(is.na(pik))) stop("there are missing values in the pik vector")
 n=sum(pik)
-if(n!=trunc(n)) stop("the pik's sum is not integer")
+if(abs(n-trunc(n))<eps) n=trunc(n) 
+else stop("the sum of pik is not integer")
 list = pik > eps & pik < 1 - eps
 pikb = pik[list]
 N = length(pikb)
