@@ -2,6 +2,8 @@
 function(pik) 
 { 
 n=sum(pik)
+if(abs(n-trunc(n))<1e-6) n=trunc(n) 
+else stop("the sum of pik is not integer")
 if(n>=2)
 {
 pik2=pik[pik!=1]
