@@ -1,6 +1,8 @@
 UPsystematicpi2<-function(pik) 
 {
-    if(sum(pik)%%1!=0) stop("The sample size is not fixed")
+    n=sum(pik)
+    if(abs(n-trunc(n))<1e-6) n=trunc(n) 
+    else stop("the sum of pik is not integer")
     pik1 = pik[pik > 0 & pik < 1]
     N = length(pik1)
     Vk = cumsum(pik1)
