@@ -3,7 +3,8 @@ function(pik,eps=1e-6)
 {
 if(any(is.na(pik))) stop("there are missing values in the pik vector")
 n=sum(pik)
-if(n!=trunc(n)) stop("the sum of pik vector is not integer")
+if(abs(n-trunc(n))<eps) n=trunc(n) 
+else stop("the sum of pik is not integer")
 list = pik > eps & pik < 1 - eps
 pikb = pik[list]
 N = length(pikb)
